@@ -55,6 +55,7 @@ from livestyled.models.ticket import Ticket
 from livestyled.models.ticket_auth import TicketAuth
 from livestyled.models.ticket_integration import TicketIntegration
 from livestyled.models.user import User, UserAlias, UserAliasType, UserEmail, UserInfo, UserSSO
+from livestyled.models.user_cohort import UserCohort
 from livestyled.models.venue import Venue
 from livestyled.models.widget import Widget, WidgetVariation
 
@@ -121,6 +122,7 @@ __all__ = [
     UserEmail,
     UserInfo,
     User,
+    UserCohort,
     UserSSO,
     Venue,
     Widget,
