@@ -7,8 +7,8 @@ class BannerTranslation:
             self,
             id: int or str,
             language: str,
-            title: str,
-            url: str or None,
+            url: str or None = None,
+            title: str or None = None,
             description: str or None = None,
             subtitle: Optional[str] = None,
             button_label: Optional[str] = None,
